@@ -45,7 +45,6 @@
 (test-error #t (scm->json-string -inf.0))
 (test-error #t (scm->json-string +nan.0))
 
-
 ;; Strings
 (test-equal "\"hello guile!\"" (scm->json-string "hello guile!"))
 (test-equal "\"你好 guile!\"" (scm->json-string "你好 guile!"))
@@ -54,6 +53,19 @@
 (test-equal "\"</script>\"" (scm->json-string "</script>"))
 (test-equal "\"<\\/script>\"" (scm->json-string "</script>" #:solidus #t))
 
+;; Strings (special characters)
+(test-equal "\"quotation mark:\\\"\"" (scm->json-string "quotation mark:\""))
+(test-equal "\"reverse solidus:\\\\\"" (scm->json-string "reverse solidus:\\"))
+(test-equal "\"solidus:/\"" (scm->json-string "solidus:/"))
+(test-equal "\"solidus:\\/\"" (scm->json-string "solidus:/" #:solidus #t))
+(test-equal "\"backspace:\\b\"" (scm->json-string "backspace:"))
+(test-equal "\"form feed:\\f\"" (scm->json-string "form feed:"))
+(test-equal "\"line feed:\\n\"" (scm->json-string "line feed:
+"))
+(test-equal "\"carriage return:\\r\"" (scm->json-string "carriage return:
+"))
+(test-equal "\"horizontal tab:\\t\"" (scm->json-string "horizontal tab:	"))
+
 ;; Boolean
 (test-equal "true" (scm->json-string #t))
 (test-equal "false" (scm->json-string #f))
